@@ -36,18 +36,18 @@ class PythonProxyBase(FrameworkTransformer):
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setName(self, value: str) -> "PythonProxyBase":
-        self._paramMap[self.name] = value  # type: ignore
+        self._paramMap[self.name] = value
         return self
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getName(self) -> str:
-        return self.getOrDefault(self.name or self.__class__.__name__)
+        return self.getOrDefault(self.name) or self.__class__.__name__
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setProgressLogger(self, value: ProgressLogger) -> "PythonProxyBase":
-        self._paramMap[self.progress_logger] = value  # type: ignore
+        self._paramMap[self.progress_logger] = value
         return self
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getProgressLogger(self) -> Optional[ProgressLogger]:
-        return self.getOrDefault(self.progress_logger)  # type: ignore
+        return self.getOrDefault(self.progress_logger)
